@@ -1,12 +1,12 @@
-import pickle
 import os
+import joblib
 
 basepath=os.path.dirname(os.path.realpath(__file__))
 path_model=os.path.join(basepath,'lang_detect.model')
-path_vect=os.path.join(basepath,'vectorizer.pkl')
+path_vect=os.path.join(basepath,'vectorizer.vect')
 
-naive_classifier=pickle.load(open(path_model,'rb'))
-vectorizer=pickle.load(open(path_vect,'rb'))
+naive_classifier=joblib.load(open(path_model,'rb'))
+vectorizer=joblib.load(open(path_vect,'rb'))
 
 def detect(text):
     test=vectorizer.transform([text])
